starcluster.image.ImageCreator

Package starcluster :: Module image :: Class ImageCreator |
[hide private]
[frames] | no frames]

# Class ImageCreator

source code

Base class for S3/EBS Image Creators. Handles fetching the host and setting up a connection object as well as setting common attributes (description, kernel_id, ramdisk_id)

easy_ec2 must be an awsutils.EasyEC2 object

instance_id is the id of the instance to be imaged

key_location must point to the private key file corresponding to the keypair used to launch instance_id

Instance Methods | [hide private]
__init__(self, easy_ec2, instance_id, key_location, description=None, kernel_id=None, ramdisk_id=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
clean_private_data(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, easy_ec2, instance_id, key_location, description=None, kernel_id=None, ramdisk_id=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)